@@ -59,8 +59,8 @@ class table:
     (data) if you do not want to import from a data file, you can pass a
         np.array to this argument. The datname you specified will be ignored.
     """
-    def __init__(self, datname, AutoInsert=True, units={},
-                 sheet=None, data=None, delimiter=',', skiprows=None):
+    def __init__(self, datname, AutoInsert=True, units={}, sheet=None,
+                 data=None, delimiter=',', skiprows=None, noNames=False):
         self.units = units
         if data is not None:
             if isinstance(data, pd.DataFrame):
@@ -92,6 +92,12 @@ class table:
             else:
                 self.data = pd.read_csv(name + '.' + ext, delimiter=delimiter,
                                         skiprows=skiprows)
+                if noNames:
+                    names = list(map(str,range(len(self.data.columns))))
+                    self.data = pd.read_csv(name + '.' + ext,
+                                            delimiter=delimiter,
+                                            skiprows=skiprows, header=0, 
+                                            names=names)
 
         self.giveUnits(units)
         self.formulas = {}
